@@ -1,6 +1,7 @@
 import logging
 import os
 import random
+from tempfile import TemporaryDirectory, NamedTemporaryFile
 
 from fsspec.implementations.local import LocalFileSystem
 
@@ -167,6 +168,20 @@ def test_read_total_nb_vectors(tmpdir):
     assert sum(file_counts) == actual_count
 
 
+def test_test_read_total_nb_vectors_with_empty_file():
+    with TemporaryDirectory() as tmp_empty_dir:
+        with NamedTemporaryFile() as tmp_file:
+            df = pd.DataFrame({"embedding": [], "id": []})
+            tmp_path = os.path.join(tmp_empty_dir, tmp_file.name)
+            df.to_parquet(tmp_path)
+            actual_count, actual_dim, file_counts = read_total_nb_vectors_and_dim(
+                [tmp_path], file_format="parquet", embedding_column_name="embedding"
+            )
+            assert actual_count == 0
+            assert actual_dim is None
+            assert file_counts == [0]
+
+
 def test_get_file_list_with_single_input(tmpdir):
     tmp_dir, _, _, _, _ = build_test_collection_parquet(tmpdir, tmpdir_name="a", nb_files=2)
     fs, paths = get_file_list(path=tmp_dir, file_format="parquet")
